@@ -73,7 +73,7 @@ KileTable::KileTable(TQWidget *dialog, TQWidget *parent, const char *name) : TQT
    setLeftMargin(0);
    setVScrollBarMode(TQScrollView::AlwaysOff);
    setHScrollBarMode(TQScrollView::AlwaysOff);
-   setFocusPolicy(TQ_NoFocus);
+   setFocusPolicy(TQWidget::NoFocus);
 
    horizontalHeader()->setResizeEnabled(false);
    horizontalHeader()->setClickEnabled(false);
