@@ -61,7 +61,7 @@ class ConfigTest
 
 class Tester : public TQObject
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
