@@ -134,7 +134,7 @@ Kile::Kile( bool allowRestore, TQWidget *parent, const char *name ) :
 	setupStatusBar();
 
 	m_topWidgetStack = new TQWidgetStack( this );
-	m_topWidgetStack->setFocusPolicy(TQ_NoFocus);
+	m_topWidgetStack->setFocusPolicy(TQWidget::NoFocus);
 
 	m_horizontalSplitter = new TQSplitter(Qt::Horizontal,m_topWidgetStack, "horizontalSplitter" );
 
@@ -304,7 +304,7 @@ void Kile::setupStructureView()
 {
 	m_kwStructure = new KileWidget::Structure(this, m_sideBar);
 	m_sideBar->addTab(m_kwStructure, SmallIcon("view_tree"), i18n("Structure"));
-	m_kwStructure->setFocusPolicy(TQ_ClickFocus);
+	m_kwStructure->setFocusPolicy(TQWidget::ClickFocus);
 	connect(TQT_TQOBJECT(this), TQT_SIGNAL(configChanged()), m_kwStructure, TQT_SIGNAL(configChanged()));
 	connect(m_kwStructure, TQT_SIGNAL(setCursor(const KURL &,int,int)), TQT_TQOBJECT(this), TQT_SLOT(setCursor(const KURL &,int,int)));
 	connect(m_kwStructure, TQT_SIGNAL(fileOpen(const KURL&, const TQString & )), docManager(), TQT_SLOT(fileOpen(const KURL&, const TQString& )));
@@ -426,7 +426,7 @@ void Kile::setupAbbreviationView()
 void Kile::setupBottomBar()
 {
 	m_bottomBar = new KileBottomBar(KileConfig::bottomBarSize(), m_verticalSplitter);
-	m_bottomBar->setFocusPolicy(TQ_ClickFocus);
+	m_bottomBar->setFocusPolicy(TQWidget::ClickFocus);
 
 	m_logWidget = new KileWidget::LogMsg( this, m_bottomBar );
 	connect(m_logWidget, TQT_SIGNAL(showingErrorMessage(TQWidget* )), m_bottomBar, TQT_SLOT(showPage(TQWidget* )));
@@ -434,13 +434,13 @@ void Kile::setupBottomBar()
 	connect(m_logWidget, TQT_SIGNAL(setLine(const TQString& )), TQT_TQOBJECT(this), TQT_SLOT(setLine(const TQString& )));
 	connect(m_docManager,TQT_SIGNAL(printMsg(int, const TQString &, const TQString &)),m_logWidget,TQT_SLOT(printMsg(int, const TQString &, const TQString &)));
 
-	m_logWidget->setFocusPolicy(TQ_ClickFocus);
+	m_logWidget->setFocusPolicy(TQWidget::ClickFocus);
 	m_logWidget->setMinimumHeight(40);
 	m_logWidget->setReadOnly(true);
 	m_bottomBar->addTab(m_logWidget, SmallIcon("viewlog"), i18n("Log and Messages"));
 
 	m_outputWidget = new KileWidget::Output(m_bottomBar);
-	m_outputWidget->setFocusPolicy(TQ_ClickFocus);
+	m_outputWidget->setFocusPolicy(TQWidget::ClickFocus);
 	m_outputWidget->setMinimumHeight(40);
 	m_outputWidget->setReadOnly(true);
 	m_bottomBar->addTab(m_outputWidget, SmallIcon("output_win"), i18n("Output"));
@@ -1107,7 +1107,7 @@ void Kile::convertToEnc(Kate::Document *doc)
 	if (sender())
 	{
 		ConvertIO io(doc);
-		TQString name = TQString(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name()).section('_', -1);
+		TQString name = TQString(sender()->name()).section('_', -1);
 		ConvertASCIIToEnc conv = ConvertASCIIToEnc(name, &io);
 		conv.convert();
 		doc->setEncoding(ConvertMap::encodingNameFor(name));
@@ -1573,7 +1573,7 @@ void Kile::prepareForPart(const TQString & state)
 void Kile::runTool()
 {
 	focusLog();
-	TQString name = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name();
+	TQString name = sender()->name();
 	name.replace(TQRegExp("^.*tool_"), "");
 	m_manager->run(name);
 }
@@ -2311,7 +2311,7 @@ void Kile::citeViewBib()
 	}
 	else{
 		TQDataStream reply(replyData, IO_ReadOnly);
-		if (replyType == TQSTRING_OBJECT_NAME_STRING)
+		if (replyType == "TQString")
 		{
 			TQString result;
 			reply >> result;
