@@ -50,7 +50,7 @@ public:
 
 class Tag : public TDEAction
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -89,7 +89,7 @@ protected:
 */
 class InputTag : public Tag
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -136,7 +136,7 @@ private:
 */
 class InputDialog : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -172,7 +172,7 @@ private:
 
 class Select : public TDESelectAction
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
