@@ -28,21 +28,21 @@
 
 #include <kate/document.h>
 #include <kate/view.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include "kiledebug.h"
 #include <kencodingfiledialog.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kmimetype.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kprogress.h>
-#include <kfile.h>
+#include <tdefile.h>
 #include <krun.h>
 #include <kstandarddirs.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
 #include <kpushbutton.h>
 #include <kurl.h>
 #include <kurldrag.h>
-#include <kfileitem.h>
+#include <tdefileitem.h>
 
 #include "kileeventfilter.h"
 #include "kileuntitled.h"
@@ -799,8 +799,8 @@ void Manager::fileSaveAll(bool amAutoSaving, bool disUntitled )
 					
     					// get the right permissions, start with safe default
 					mode_t  perms = 0600;
-					KIO::UDSEntry fentry;
-					if (KIO::NetAccess::stat (url, fentry, kapp->mainWidget()))
+					TDEIO::UDSEntry fentry;
+					if (TDEIO::NetAccess::stat (url, fentry, kapp->mainWidget()))
 					{
 						KILE_DEBUG () << "stating successful: " << url.prettyURL() << endl;
 						KFileItem item (fentry, url);
@@ -809,9 +809,9 @@ void Manager::fileSaveAll(bool amAutoSaving, bool disUntitled )
 
     					// first del existing file if any, than copy over the file we have
 					// failure if a: the existing file could not be deleted, b: the file could not be copied
-					if ( (!KIO::NetAccess::exists( backupUrl, false, kapp->mainWidget() )
-					      || KIO::NetAccess::del( backupUrl, kapp->mainWidget() ) )
-					      && KIO::NetAccess::file_copy( url, backupUrl, perms, true, false, kapp->mainWidget() ) )
+					if ( (!TDEIO::NetAccess::exists( backupUrl, false, kapp->mainWidget() )
+					      || TDEIO::NetAccess::del( backupUrl, kapp->mainWidget() ) )
+					      && TDEIO::NetAccess::file_copy( url, backupUrl, perms, true, false, kapp->mainWidget() ) )
 					{
 						KILE_DEBUG()<<"backing up successful ("<<url.prettyURL()<<" -> "<<backupUrl.prettyURL()<<")"<<endl;
 					}
@@ -932,7 +932,7 @@ void Manager::fileSaveAs(Kate::View* view)
 		if(info->getType() == KileDocument::LaTeX) {
 			saveURL = Info::makeValidTeXURL(saveURL, m_ki->extensions()->isTexFile(saveURL), false); // don't check for file existence
 		}
-		if(KIO::NetAccess::exists(saveURL, true, kapp->mainWidget())) // check for writing possibility
+		if(TDEIO::NetAccess::exists(saveURL, true, kapp->mainWidget())) // check for writing possibility
 		{
 			int r =  KMessageBox::warningContinueCancel(m_ki->parentWidget(), i18n("A file with the name \"%1\" exists already. Do you want to overwrite it ?").arg(saveURL.fileName()), i18n("Overwrite File ?"), KGuiItem(i18n("&Overwrite")), TQString());
 			if(r != KMessageBox::Continue)
@@ -942,10 +942,26 @@ void Manager::fileSaveAs(Kate::View* view)
 		}
 		break;
 	}
-	doc->setEncoding(result.encoding);
-	if(!doc->saveAs(saveURL))
-	{
-		return;
+	if(doc->encoding().lower() != result.encoding.lower()) {
+		// save the document twice if the user has selected a different encoding;
+		// this works around a bug in KatePart in the 'setEncoding' method, which 
+		// enforces a reload on every change of the encoding, and as a consequence the
+		// user sees a document-modified dialog
+		if(!doc->saveAs(saveURL))
+		{
+			return;
+		}
+		doc->setEncoding(result.encoding);
+		if(!doc->save())
+		{
+			return;
+		}
+	}
+	else {
+		if(!doc->saveAs(saveURL))
+		{
+			return;
+		}
 	}
 	if(oldURL != saveURL)
 	{
@@ -1770,7 +1786,7 @@ void Manager::projectShow()
 		{
 			TQString itempath = item->path();
 
-			// called from KAction 'Show projects...': find the first opened 
+			// called from TDEAction 'Show projects...': find the first opened 
 			// LaTeX document or, if that fails, any other opened file
 			TQStringList extlist = TQStringList::split(" ",m_ki->extensions()->latexDocuments() + ' ' + m_ki->extensions()->latexPackages());
 			for ( TQStringList::Iterator it=extlist.begin(); it!=extlist.end(); ++it )
