@@ -810,12 +810,12 @@ void LaTeXInfo::updateStructLevelInfo() {
 
 void LaTeXInfo::installEventFilters(KTextEditor::View *view)
 {
-	view->focusProxy()->installEventFilter(const_cast<TQObject*>(m_eventFilter));
+	view->focusProxy()->installEventFilter(m_eventFilter);
 }
 
 void LaTeXInfo::removeInstalledEventFilters(KTextEditor::View *view)
 {
-	view->focusProxy()->removeEventFilter(const_cast<TQObject*>(m_eventFilter));
+	view->focusProxy()->removeEventFilter(m_eventFilter);
 }
 
 BracketResult LaTeXInfo::matchBracket(uint &l, uint &pos)
