@@ -19,7 +19,7 @@
    the Free Software Foundation, Inc., 51 Franklin Steet, Fifth Floor,
    Boston, MA 02110-1301, USA.
 
-   Original from kdebase / kate
+   Original from tdebase / kate
 
    changes: 2005-11-27 (dani)
     - add a search for all files of a Kile project
@@ -55,18 +55,18 @@
 #include <tqcursor.h>
 
 #include <kcombobox.h>
-#include <kapplication.h>
-#include <kaccelmanager.h>
+#include <tdeapplication.h>
+#include <tdeaccelmanager.h>
 #include <kbuttonbox.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kprocess.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kurlrequester.h>
 #include <kurlcompletion.h>
 #include <klineedit.h>
-#include <klistbox.h>
+#include <tdelistbox.h>
 #include "kiledebug.h"
 
 #include "kileconfig.h"
@@ -199,7 +199,7 @@ KileGrepDialog::KileGrepDialog(TQWidget *parent, KileInfo *ki, KileGrep::Mode mo
 	filtergrouplayout->setColStretch(1,1);
 
 	// result box
-	resultbox = new KListBox(page);
+	resultbox = new TDEListBox(page);
 	resultbox->setMinimumHeight(150);
 
 	// button box
@@ -210,7 +210,7 @@ KileGrepDialog::KileGrepDialog(TQWidget *parent, KileInfo *ki, KileGrep::Mode mo
 	clear_button = actionbox->addButton(i18n("&Clear"));
 	clear_button->setEnabled(false);
 	actionbox->addStretch();
-#if KDE_VERSION >= KDE_MAKE_VERSION(3,3,0)
+#if TDE_VERSION >= TDE_MAKE_VERSION(3,3,0)
 	close_button = actionbox->addButton(KStdGuiItem::close());
 #else
         close_button = actionbox->addButton(i18n("Cl&ose"));
@@ -244,7 +244,7 @@ KileGrepDialog::KileGrepDialog(TQWidget *parent, KileInfo *ki, KileGrep::Mode mo
 	// TQListBox::property( "text" ) failed:
 	// 	property invalid or does not exist
 	// Anyone an idea?
-	KAcceleratorManager::manage( this );
+	TDEAcceleratorManager::manage( this );
 
 	TQWhatsThis::add(pattern_combo,
 		i18n("Enter the regular expression you want to search for here.<br>"
@@ -478,12 +478,12 @@ void KileGrepDialog::slotItemSelected(const TQString& item)
 
 void KileGrepDialog::startGrep()
 {
-	childproc = new KProcess();
+	childproc = new TDEProcess();
 	childproc->setUseShell(true);
 
 	if ( m_mode == KileGrep::Project )
 	{
-		TQString command = buildProjectCommand() + ' ' + KProcess::quote(m_projectfiles[m_grepJobs-1]);
+		TQString command = buildProjectCommand() + ' ' + TDEProcess::quote(m_projectfiles[m_grepJobs-1]);
 		KILE_DEBUG() << "\tgrep (project): " <<  command << endl;
 		(*childproc) << TQStringList::split(' ',command);
 	}
@@ -495,14 +495,14 @@ void KileGrepDialog::startGrep()
 	}
 	m_grepJobs--;
 
-	connect( childproc, TQT_SIGNAL(processExited(KProcess *)),
+	connect( childproc, TQT_SIGNAL(processExited(TDEProcess *)),
 		TQT_SLOT(childExited()) );
-	connect( childproc, TQT_SIGNAL(receivedStdout(KProcess *, char *, int)),
-		TQT_SLOT(receivedOutput(KProcess *, char *, int)) );
-	connect( childproc, TQT_SIGNAL(receivedStderr(KProcess *, char *, int)),
-		TQT_SLOT(receivedErrOutput(KProcess *, char *, int)) );
+	connect( childproc, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)),
+		TQT_SLOT(receivedOutput(TDEProcess *, char *, int)) );
+	connect( childproc, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)),
+		TQT_SLOT(receivedErrOutput(TDEProcess *, char *, int)) );
 
-	childproc->start(KProcess::NotifyOnExit, KProcess::AllOutput);
+	childproc->start(TDEProcess::NotifyOnExit, TDEProcess::AllOutput);
 }
 
 void KileGrepDialog::processOutput()
@@ -530,13 +530,13 @@ void KileGrepDialog::processOutput()
 	kapp->processEvents();
 }
 
-void KileGrepDialog::receivedOutput(KProcess */*proc*/, char *buffer, int buflen)
+void KileGrepDialog::receivedOutput(TDEProcess */*proc*/, char *buffer, int buflen)
 {
 	buf += TQString::fromLocal8Bit(buffer, buflen);
 	processOutput();
 }
 
-void KileGrepDialog::receivedErrOutput(KProcess */*proc*/, char *buffer, int buflen)
+void KileGrepDialog::receivedErrOutput(TDEProcess */*proc*/, char *buffer, int buflen)
 {
 	errbuf += TQString::fromLocal8Bit( buffer, buflen );
 }
@@ -619,7 +619,7 @@ TQString KileGrepDialog::getShellPattern()
 	TQString pattern = getPattern();
 	pattern.replace("'", "'\\''");
 	return '\'' + pattern + '\'';
-	//return KProcess::quote(pattern);
+	//return TDEProcess::quote(pattern);
 }
 
 
@@ -631,11 +631,8 @@ TQString KileGrepDialog::buildFilesCommand()
 		files_temp = filter_list[filter_combo->currentItem()];
 	else
 		files_temp = filter_combo->currentText();
-
-	if (files_temp.right(1) != ",")
-		files_temp = files_temp + ',';
-
-	TQStringList tokens = TQStringList::split ( ",", files_temp, false );
+	
+	TQStringList tokens = TQStringList::split ( " ", files_temp, false );
 	TQStringList::Iterator it = tokens.begin();
 	if (it != tokens.end())
 	{
@@ -648,7 +645,7 @@ TQString KileGrepDialog::buildFilesCommand()
 
 	TQString shell_command;
 	shell_command += "find ";
-	shell_command += KProcess::quote(dir_combo->url());
+	shell_command += TDEProcess::quote(dir_combo->url());
 	shell_command += " \\( -name ";
 	shell_command += files;
 	shell_command += " \\)";
