@@ -28,7 +28,7 @@ namespace KileWidget
 {
 	class LogMsg : public KTextEdit  
 	{
-		Q_OBJECT
+		TQ_OBJECT
   
 
 	public: 
