@@ -27,10 +27,10 @@
 #include <tqdir.h>
 
 #include <ksimpleconfig.h>
-#include <klocale.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
 #include "kiledebug.h"
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 #include "kiledocumentinfo.h"
 #include "kiledocmanager.h"
@@ -304,7 +304,7 @@ void KileProject::readMakeIndexOptions()
 	TQString grp = KileTool::groupFor("MakeIndex", m_config);
 
 	//get the default value
-	KConfig *cfg = KGlobal::config();
+	TDEConfig *cfg = TDEGlobal::config();
 	cfg->setGroup(KileTool::groupFor("MakeIndex", KileTool::configName("MakeIndex", cfg)));
 	TQString deflt = cfg->readEntry("options", "'%S'.idx");
 	
@@ -487,6 +487,7 @@ bool KileProject::save()
 		m_config->writeEntry("options", makeIndexOptions() );
 	}
 
+	KILE_DEBUG() << "Check if the config file is writeable: " << m_config->checkConfigFilesWritable(false) << endl;
 	m_config->sync();
 
 	// dump();
