@@ -30,7 +30,7 @@ class SymbolView;
 */
 class KileSideBar : public TQFrame
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -88,7 +88,7 @@ protected:
 
 class KileBottomBar : public KileSideBar
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
