@@ -391,9 +391,9 @@ namespace KileTool
 	bool Base::finish(int result)
 	{
 		KILE_DEBUG() << "==KileTool::Base::finish()==============" << endl;
-		if (TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender())))
+		if (sender())
 		{
-			KILE_DEBUG() << "\tcalled by " << TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() << " " << TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->className() << endl;
+			KILE_DEBUG() << "\tcalled by " << sender()->name() << " " << sender()->className() << endl;
 		}
 		
 		if ( result == Aborted )
