@@ -93,7 +93,7 @@ void Manager::createTabs(TQWidget *parent)
 	connect(m_emptyDropWidget, TQT_SIGNAL(receivedDropEvent(TQDropEvent *)), m_ki->docManager(), TQT_SLOT(openDroppedURLs(TQDropEvent *)));
 	m_tabs = new KTabWidget(parent);
 	m_widgetStack->addWidget(m_tabs);
-	m_tabs->setFocusPolicy(TQ_ClickFocus);
+	m_tabs->setFocusPolicy(TQWidget::ClickFocus);
 	m_tabs->setTabReorderingEnabled(true);
 	m_tabs->setHoverCloseButton(true);
 	m_tabs->setHoverCloseButtonDelayed(true);
@@ -165,7 +165,7 @@ Kate::View* Manager::createTextView(KileDocument::TextInfo *info, int index)
 	
 	reflectDocumentStatus(view->getDoc(), false, 0);
 
-	view->setFocusPolicy(TQ_StrongFocus);
+	view->setFocusPolicy(TQWidget::StrongFocus);
 	view->setFocus();
 
 	emit(prepareForPart("Editor"));
