@@ -33,12 +33,12 @@ email                : holger.danielsson@t-online.de
 #include <tqregexp.h>
 
 #include <kcombobox.h>
-#include <klocale.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
 #include <klineedit.h>
 #include <kiconloader.h>
 #include <kpushbutton.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include "kiledebug.h"
 
 #include "kileconfig.h"
@@ -129,7 +129,7 @@ void EditableCheckListItem::paintCell( TQPainter *p, const TQColorGroup &cg,
 
 //////////////////// QuickDocument class ////////////////////
 
-QuickDocument::QuickDocument(KConfig *config, TQWidget *parent, const char *name, const TQString &caption) : Wizard(config, parent,name,caption)
+QuickDocument::QuickDocument(TDEConfig *config, TQWidget *parent, const char *name, const TQString &caption) : Wizard(config, parent,name,caption)
 {
 	KILE_DEBUG() << "==QuickDocument::setupGUI()============" << endl;
 	TQTabWidget *tabWidget = new TQTabWidget( this );
@@ -357,9 +357,9 @@ TQWidget *QuickDocument::setupProperties(TQTabWidget *tab)
 	label->setBuddy(m_leDate);
 
 	// set current date
-	m_leDate->setText( KGlobal::locale()->formatDate(TQDate::currentDate(), true) );
+	m_leDate->setText( TDEGlobal::locale()->formatDate(TQDate::currentDate(), true) );
 	// For KDE4:
-	//m_leDate->setText( KGlobal::locale()->formatDate(TQDate::currentDate(), KLocale::ShortDate) );
+	//m_leDate->setText( TDEGlobal::locale()->formatDate(TQDate::currentDate(), TDELocale::ShortDate) );
 
 	return personalInfo;
 }
