@@ -29,7 +29,7 @@ static const TQString MFUSprefix = "MFUS";
 
 class SymbolView : public TDEIconView
 {	
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 public:
