@@ -585,7 +585,7 @@ void TabCellDialog::initWidgets()
 
 void TabCellDialog::slotFramebuttonClicked()
 {
-	TQString name = TQString( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() ).section('_',1,1);
+	TQString name = TQString( sender()->name() ).section('_',1,1);
 	
 	int border = -1;
 	if ( name == "no" )
@@ -610,7 +610,7 @@ void TabCellDialog::slotResetClicked()
 
 void TabCellDialog::slotSeparatorClicked()
 {
-	TQString checkboxname = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name();
+	TQString checkboxname = sender()->name();
 	if ( m_cbAt->isChecked() && checkboxname=="cb_at" )
 		m_cbSep->setChecked(false);
 	else if ( m_cbSep->isChecked() && checkboxname=="cb_sep" )
@@ -744,12 +744,12 @@ bool TabularTable::eventFilter(TQObject *o, TQEvent *e)
 		TQMouseEvent *me = TQT_TQMOUSEEVENT(e);
 		if ( me->button() == Qt::RightButton ) 
 		{
-			if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(horizontalHeader()) ) 
+			if ( o == horizontalHeader() )
 			{
 				mouseContextHorizontalHeader( me->pos().x() );
 				return true;
 			} 
-			else if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(verticalHeader()) ) 
+			else if ( o == verticalHeader() )
 			{
 				mouseContextVerticalHeader( me->pos().y() );
 				return true;
